@@ -1,22 +1,22 @@
 //    SPDX-License-Identifier: LGPL-3.0-or-later
 /*
-    This file is part of FlexiBLAS, a BLAS/LAPACK interface wrapper library.
-    Copyright (C) 2013-2024 Martin Koehler
+   This file is part of FlexiBLAS, a BLAS/LAPACK interface wrapper library.
+   Copyright (C) 2013-2025 Martin Koehler
 
-    This program is free software: you can redistribute it and/or modify it
-    under the terms of the GNU General Public License as published by the Free
-    Software Foundation, either version 3 of the License, or (at your option)
-    any later version.
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Lesser General Public
+   License as published by the Free Software Foundation; either
+   version 3 of the License, or (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-    more details.
-
-    You should have received a copy of the GNU General Public License along
-    with this program. If not, see <https://www.gnu.org/licenses/>.
- */
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser General Public License for more details.
 
+   You should have received a copy of the GNU Lesser General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+   */
 
 
 
@@ -126,7 +126,7 @@ HIDDEN void __flexiblas_backend_init( flexiblas_backend_t * backend) {
         __flexiblas_setup_cblas_xerbla(backend);
 #endif
 
-	/*-----------------------------------------------------------------------------
+        /*-----------------------------------------------------------------------------
          *  Load Fortran BLAS
          *-----------------------------------------------------------------------------*/
         __flexiblas_load_fblas(backend, &load, &failed);
@@ -197,6 +197,44 @@ static void flexiblas_load_info(void *library, flexiblas_backend_t *backend)
         DPRINTF(1,"No BLAS Info found in given backend. Using default.\n");
         h_info_default(&(backend->info));
     }
+
+#if __BYTE_ORDER__ == __ORDER_BIG_ENDIAN__
+    backend->info.intel_interface = 0;
+#else
+
+    /* Get the complex return type */
+    flexiblas_complex_interface_t cpx_interface = __flexiblas_get_complex_interface(library);
+    if ( cpx_interface == FLEXIBLAS_COMPLEX_INTEL_INTERFACE) {
+        DPRINTF(1, "--> BLAS uses Intel interface for complex return values.\n");
+        backend->info.intel_interface = 1;
+    } else if ( cpx_interface == FLEXIBLAS_COMPLEX_GNU_INTERFACE) {
+        DPRINTF(1, "--> BLAS uses GNU interface for complex return values.\n");
+        backend->info.intel_interface = 0;
+    } else {
+        DPRINTF(1,"Could not detect the complex-return-value interface style. Using information from backend, if provided.\n");
+    }
+
+#endif
+
+    /* Get the Integer size of the backend */
+    flexiblas_interface_t interface = __flexiblas_get_interface(library);
+    if ( interface == FLEXIBLAS_INTERFACE_LP64 )
+    {
+        DPRINTF(1, "--> BLAS uses LP64.\n");
+#ifdef FLEXIBLAS_INTEGER8
+        DPRINTF_WARN(0, "The selected BLAS backend uses 4-byte integers (e.g. the LP64 model), but FlexiBLAS was configured with -DINTEGER8=ON. This causes problems in almost all use cases. Please select a different backend or recompile FlexiBLAS.\n");
+#endif
+    }
+    else if ( interface == FLEXIBLAS_INTERFACE_ILP64 )
+    {
+        DPRINTF(1, "--> BLAS uses ILP64.\n");
+#ifndef FLEXIBLAS_INTEGER8
+        DPRINTF_WARN(0, "The selected BLAS backend uses 8-byte integers (e.g. the ILP64 model), but FlexiBLAS was configured with -DINTEGER8=OFF. This causes problems in almost all uses cases. Please select a different backend or recompile FlexiBLAS.\n");
+#endif
+    } else {
+        DPRINTF(1, "--> BLAS integer model unknown.\n");
+    }
+
 }
 
 /*-----------------------------------------------------------------------------
@@ -259,7 +297,7 @@ static flexiblas_backend_t * flexiblas_load_library_from_init (flexiblas_mgmt_t
             flexiblas_mgmt_location_t loc;
             char *tmp = strdup(env_FLEXIBLAS);
             tmp = uppercase(tmp);
-            DPRINTF_WARN(1,"\"%s\" does not seem to a shared library. Search inside the FlexiBLAS configuration..\n", tmp);
+            DPRINTF_WARN(1,"\"%s\" does not seem to be a shared library. Search inside the FlexiBLAS configuration..\n", tmp);
 
             clibrary = (char*) malloc(sizeof(char)*32768);
             if ( flexiblas_mgmt_blas_get2(config, &loc, tmp, clibrary, NULL)) {
@@ -737,6 +775,8 @@ __attribute__((constructor))
         __flexiblas_hooks->initialized  = 0;
 
         dlsym((void *) 0, "flexiblas_verbosity");
+        dlsym((void *) 0, "flexiblas_chain_zlaqr5");
+
 
         int hooks_to_load = 0;
         char ** hook_load_list = NULL;
@@ -816,13 +856,8 @@ __attribute__((constructor))
         }
 
 
-        continue_load:
+continue_load:
         return;
-
-
-
-
-
     }
 
 
@@ -843,7 +878,6 @@ __attribute__((destructor))
             dlclose(__flexiblas_hooks->handles[k]);
         }
         free(__flexiblas_hooks);
-        nloaded_backends = 0;
         __flexiblas_free_paths();
         __flexiblas_exit_hook();
 
@@ -864,6 +898,7 @@ __attribute__((destructor))
         }
         free(loaded_backends);
 
+        nloaded_backends = 0;
         dlclose(__flexiblas_blas_fallback);
 #ifdef FLEXIBLAS_LAPACK
         dlclose(__flexiblas_lapack_fallback);
