@@ -8,10 +8,14 @@ F77_INT link_xerbla=TRUE;
 char *cblas_rout;
 
 #ifdef F77_Char
-void F77_xerbla(F77_Char F77_srname, void *vinfo);
+void F77_xerbla(F77_Char F77_srname, void *vinfo
 #else
-void F77_xerbla(char *srname, void *vinfo);
+void F77_xerbla(char *srname, void *vinfo
 #endif
+#ifdef BLAS_FORTRAN_STRLEN_END
+  , FORTRAN_STRLEN
+#endif
+);
 
 void chkxer(void) {
    extern F77_INT cblas_ok, cblas_lerr, cblas_info;
@@ -24,21 +28,27 @@ void chkxer(void) {
    cblas_lerr = 1 ;
 }
 
-void F77_s2chke(char *rout) {
+void F77_s2chke(char *rout
+#ifdef BLAS_FORTRAN_STRLEN_END
+  , FORTRAN_STRLEN rout_len
+#endif
+) {
    char *sf = ( rout ) ;
    float  A[2] = {0.0,0.0},
           X[2] = {0.0,0.0},
           Y[2] = {0.0,0.0},
           ALPHA=0.0, BETA=0.0;
    extern F77_INT cblas_info, cblas_lerr, cblas_ok;
-   extern F77_INT RowMajorStrg;
+   extern int RowMajorStrg;
    extern char *cblas_rout;
 
+#ifndef HAS_ATTRIBUTE_WEAK_SUPPORT
    if (link_xerbla) /* call these first to link */
    {
       cblas_xerbla(cblas_info,cblas_rout,"");
-      F77_xerbla(cblas_rout,&cblas_info);
+      F77_xerbla(cblas_rout,&cblas_info, 1);
    }
+#endif
 
    cblas_ok = TRUE ;
    cblas_lerr = PASSED ;
