@@ -3,29 +3,31 @@
     This file is part of FlexiBLAS, a BLAS/LAPACK interface wrapper library.
     Copyright (C) 2013-2024 Martin Koehler
 
-    This program is free software: you can redistribute it and/or modify it
-    under the terms of the GNU General Public License as published by the Free
-    Software Foundation, either version 3 of the License, or (at your option)
-    any later version.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 3 of the License, or (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-    more details.
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program. If not, see <https://www.gnu.org/licenses/>.
- */
+    You should have received a copy of the GNU Lesser General Public License
+    along with this program; if not, write to the Free Software Foundation,
+    Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
 
 
 
 
-#ifndef LAPACK_3_5_0_H
 
-#define LAPACK_3_5_0_H
 
-char *lapack_3_5_0[] = {
-    "cbbcsd",
+#ifndef LAPACK_3_2_0_H
+
+#define LAPACK_3_2_0_H
+
+char *lapack_3_2_0 [] = {
     "cbdsqr",
     "cgbbrd",
     "cgbcon",
@@ -59,18 +61,12 @@ char *lapack_3_5_0[] = {
     "cgelss",
     "cgelsx",
     "cgelsy",
-    "cgemqrt",
     "cgeql2",
     "cgeqlf",
     "cgeqp3",
     "cgeqpf",
     "cgeqr2",
-    "cgeqr2p",
     "cgeqrf",
-    "cgeqrfp",
-    "cgeqrt",
-    "cgeqrt2",
-    "cgeqrt3",
     "cgerfs",
     "cgerq2",
     "cgerqf",
@@ -113,7 +109,6 @@ char *lapack_3_5_0[] = {
     "chbgvx",
     "chbtrd",
     "checon",
-    "checon_rook",
     "cheequb",
     "cheev",
     "cheevd",
@@ -126,22 +121,13 @@ char *lapack_3_5_0[] = {
     "chegvx",
     "cherfs",
     "chesv",
-    "chesv_rook",
     "chesvx",
-    "cheswapr",
     "chetd2",
     "chetf2",
-    "chetf2_rook",
     "chetrd",
     "chetrf",
-    "chetrf_rook",
     "chetri",
-    "chetri2",
-    "chetri2x",
-    "chetri_rook",
     "chetrs",
-    "chetrs2",
-    "chetrs_rook",
     "chfrk",
     "chgeqz",
     "chla_transtype",
@@ -181,7 +167,6 @@ char *lapack_3_5_0[] = {
     "clags2",
     "clagtm",
     "clahef",
-    "clahef_rook",
     "clahqr",
     "clahr2",
     "clahrd",
@@ -205,7 +190,6 @@ char *lapack_3_5_0[] = {
     "clantp",
     "clantr",
     "clapll",
-    "clapmr",
     "clapmt",
     "claqgb",
     "claqge",
@@ -229,7 +213,7 @@ char *lapack_3_5_0[] = {
     "clarf",
     "clarfb",
     "clarfg",
-    "clarfgp",
+    "clarfp",
     "clarft",
     "clarfx",
     "clargv",
@@ -246,7 +230,6 @@ char *lapack_3_5_0[] = {
     "classq",
     "claswp",
     "clasyf",
-    "clasyf_rook",
     "clatbs",
     "clatdf",
     "clatps",
@@ -313,27 +296,16 @@ char *lapack_3_5_0[] = {
     "cstemr",
     "csteqr",
     "csycon",
-    "csycon_rook",
-    "csyconv",
     "csyequb",
     "csymv",
     "csyr",
     "csyrfs",
     "csysv",
-    "csysv_rook",
     "csysvx",
-    "csyswapr",
     "csytf2",
-    "csytf2_rook",
     "csytrf",
-    "csytrf_rook",
     "csytri",
-    "csytri2",
-    "csytri2x",
-    "csytri_rook",
     "csytrs",
-    "csytrs2",
-    "csytrs_rook",
     "ctbcon",
     "ctbrfs",
     "ctbtrs",
@@ -350,10 +322,6 @@ char *lapack_3_5_0[] = {
     "ctgsy2",
     "ctgsyl",
     "ctpcon",
-    "ctpmqrt",
-    "ctpqrt",
-    "ctpqrt2",
-    "ctprfb",
     "ctprfs",
     "ctptri",
     "ctptrs",
@@ -373,15 +341,6 @@ char *lapack_3_5_0[] = {
     "ctrttp",
     "ctzrqf",
     "ctzrzf",
-    "cunbdb",
-    "cunbdb1",
-    "cunbdb2",
-    "cunbdb3",
-    "cunbdb4",
-    "cunbdb5",
-    "cunbdb6",
-    "cuncsd",
-    "cuncsd2by1",
     "cung2l",
     "cung2r",
     "cungbr",
@@ -408,7 +367,6 @@ char *lapack_3_5_0[] = {
     "cunmtr",
     "cupgtr",
     "cupmtr",
-    "dbbcsd",
     "dbdsdc",
     "dbdsqr",
     "ddisna",
@@ -445,18 +403,12 @@ char *lapack_3_5_0[] = {
     "dgelss",
     "dgelsx",
     "dgelsy",
-    "dgemqrt",
     "dgeql2",
     "dgeqlf",
     "dgeqp3",
     "dgeqpf",
     "dgeqr2",
-    "dgeqr2p",
     "dgeqrf",
-    "dgeqrfp",
-    "dgeqrt",
-    "dgeqrt2",
-    "dgeqrt3",
     "dgerfs",
     "dgerq2",
     "dgerqf",
@@ -503,8 +455,6 @@ char *lapack_3_5_0[] = {
     "dlacon",
     "dlacpy",
     "dladiv",
-    "dladiv1",
-    "dladiv2",
     "dlae2",
     "dlaebz",
     "dlaed0",
@@ -537,7 +487,11 @@ char *lapack_3_5_0[] = {
     "dlals0",
     "dlalsa",
     "dlalsd",
+    "dlamc1",
+    "dlamc2",
     "dlamc3",
+    "dlamc4",
+    "dlamc5",
     "dlamch",
     "dlamrg",
     "dlaneg",
@@ -555,7 +509,6 @@ char *lapack_3_5_0[] = {
     "dlantr",
     "dlanv2",
     "dlapll",
-    "dlapmr",
     "dlapmt",
     "dlapy2",
     "dlapy3",
@@ -578,7 +531,7 @@ char *lapack_3_5_0[] = {
     "dlarf",
     "dlarfb",
     "dlarfg",
-    "dlarfgp",
+    "dlarfp",
     "dlarft",
     "dlarfx",
     "dlargv",
@@ -594,8 +547,6 @@ char *lapack_3_5_0[] = {
     "dlarrr",
     "dlarrv",
     "dlartg",
-    "dlartgp",
-    "dlartgs",
     "dlartv",
     "dlaruv",
     "dlarz",
@@ -629,7 +580,6 @@ char *lapack_3_5_0[] = {
     "dlaswp",
     "dlasy2",
     "dlasyf",
-    "dlasyf_rook",
     "dlat2s",
     "dlatbs",
     "dlatdf",
@@ -642,15 +592,6 @@ char *lapack_3_5_0[] = {
     "dlauum",
     "dopgtr",
     "dopmtr",
-    "dorbdb",
-    "dorbdb1",
-    "dorbdb2",
-    "dorbdb3",
-    "dorbdb4",
-    "dorbdb5",
-    "dorbdb6",
-    "dorcsd",
-    "dorcsd2by1",
     "dorg2l",
     "dorg2r",
     "dorgbr",
@@ -755,8 +696,6 @@ char *lapack_3_5_0[] = {
     "dstevr",
     "dstevx",
     "dsycon",
-    "dsycon_rook",
-    "dsyconv",
     "dsyequb",
     "dsyev",
     "dsyevd",
@@ -769,22 +708,13 @@ char *lapack_3_5_0[] = {
     "dsygvx",
     "dsyrfs",
     "dsysv",
-    "dsysv_rook",
     "dsysvx",
-    "dsyswapr",
     "dsytd2",
     "dsytf2",
-    "dsytf2_rook",
     "dsytrd",
     "dsytrf",
-    "dsytrf_rook",
     "dsytri",
-    "dsytri2",
-    "dsytri2x",
-    "dsytri_rook",
     "dsytrs",
-    "dsytrs2",
-    "dsytrs_rook",
     "dtbcon",
     "dtbrfs",
     "dtbtrs",
@@ -801,10 +731,6 @@ char *lapack_3_5_0[] = {
     "dtgsy2",
     "dtgsyl",
     "dtpcon",
-    "dtpmqrt",
-    "dtpqrt",
-    "dtpqrt2",
-    "dtprfb",
     "dtprfs",
     "dtptri",
     "dtptrs",
@@ -845,7 +771,6 @@ char *lapack_3_5_0[] = {
     "izmax1",
     "lsame",
     "lsamen",
-    "sbbcsd",
     "sbdsdc",
     "sbdsqr",
     "scsum1",
@@ -884,18 +809,12 @@ char *lapack_3_5_0[] = {
     "sgelss",
     "sgelsx",
     "sgelsy",
-    "sgemqrt",
     "sgeql2",
     "sgeqlf",
     "sgeqp3",
     "sgeqpf",
     "sgeqr2",
-    "sgeqr2p",
     "sgeqrf",
-    "sgeqrfp",
-    "sgeqrt",
-    "sgeqrt2",
-    "sgeqrt3",
     "sgerfs",
     "sgerq2",
     "sgerqf",
@@ -942,8 +861,6 @@ char *lapack_3_5_0[] = {
     "slacon",
     "slacpy",
     "sladiv",
-    "sladiv1",
-    "sladiv2",
     "slae2",
     "slaebz",
     "slaed0",
@@ -976,7 +893,11 @@ char *lapack_3_5_0[] = {
     "slals0",
     "slalsa",
     "slalsd",
+    "slamc1",
+    "slamc2",
     "slamc3",
+    "slamc4",
+    "slamc5",
     "slamch",
     "slamrg",
     "slaneg",
@@ -994,7 +915,6 @@ char *lapack_3_5_0[] = {
     "slantr",
     "slanv2",
     "slapll",
-    "slapmr",
     "slapmt",
     "slapy2",
     "slapy3",
@@ -1017,7 +937,7 @@ char *lapack_3_5_0[] = {
     "slarf",
     "slarfb",
     "slarfg",
-    "slarfgp",
+    "slarfp",
     "slarft",
     "slarfx",
     "slargv",
@@ -1033,8 +953,6 @@ char *lapack_3_5_0[] = {
     "slarrr",
     "slarrv",
     "slartg",
-    "slartgp",
-    "slartgs",
     "slartv",
     "slaruv",
     "slarz",
@@ -1068,7 +986,6 @@ char *lapack_3_5_0[] = {
     "slaswp",
     "slasy2",
     "slasyf",
-    "slasyf_rook",
     "slatbs",
     "slatdf",
     "slatps",
@@ -1080,15 +997,6 @@ char *lapack_3_5_0[] = {
     "slauum",
     "sopgtr",
     "sopmtr",
-    "sorbdb",
-    "sorbdb1",
-    "sorbdb2",
-    "sorbdb3",
-    "sorbdb4",
-    "sorbdb5",
-    "sorbdb6",
-    "sorcsd",
-    "sorcsd2by1",
     "sorg2l",
     "sorg2r",
     "sorgbr",
@@ -1190,8 +1098,6 @@ char *lapack_3_5_0[] = {
     "sstevr",
     "sstevx",
     "ssycon",
-    "ssycon_rook",
-    "ssyconv",
     "ssyequb",
     "ssyev",
     "ssyevd",
@@ -1204,22 +1110,13 @@ char *lapack_3_5_0[] = {
     "ssygvx",
     "ssyrfs",
     "ssysv",
-    "ssysv_rook",
     "ssysvx",
-    "ssyswapr",
     "ssytd2",
     "ssytf2",
-    "ssytf2_rook",
     "ssytrd",
     "ssytrf",
-    "ssytrf_rook",
     "ssytri",
-    "ssytri2",
-    "ssytri2x",
-    "ssytri_rook",
     "ssytrs",
-    "ssytrs2",
-    "ssytrs_rook",
     "stbcon",
     "stbrfs",
     "stbtrs",
@@ -1236,10 +1133,6 @@ char *lapack_3_5_0[] = {
     "stgsy2",
     "stgsyl",
     "stpcon",
-    "stpmqrt",
-    "stpqrt",
-    "stpqrt2",
-    "stprfb",
     "stprfs",
     "stptri",
     "stptrs",
@@ -1261,7 +1154,6 @@ char *lapack_3_5_0[] = {
     "stzrzf",
     "xerbla",
     "xerbla_array",
-    "zbbcsd",
     "zbdsqr",
     "zcgesv",
     "zcposv",
@@ -1298,18 +1190,12 @@ char *lapack_3_5_0[] = {
     "zgelss",
     "zgelsx",
     "zgelsy",
-    "zgemqrt",
     "zgeql2",
     "zgeqlf",
     "zgeqp3",
     "zgeqpf",
     "zgeqr2",
-    "zgeqr2p",
     "zgeqrf",
-    "zgeqrfp",
-    "zgeqrt",
-    "zgeqrt2",
-    "zgeqrt3",
     "zgerfs",
     "zgerq2",
     "zgerqf",
@@ -1352,7 +1238,6 @@ char *lapack_3_5_0[] = {
     "zhbgvx",
     "zhbtrd",
     "zhecon",
-    "zhecon_rook",
     "zheequb",
     "zheev",
     "zheevd",
@@ -1365,22 +1250,13 @@ char *lapack_3_5_0[] = {
     "zhegvx",
     "zherfs",
     "zhesv",
-    "zhesv_rook",
     "zhesvx",
-    "zheswapr",
     "zhetd2",
     "zhetf2",
-    "zhetf2_rook",
     "zhetrd",
     "zhetrf",
-    "zhetrf_rook",
     "zhetri",
-    "zhetri2",
-    "zhetri2x",
-    "zhetri_rook",
     "zhetrs",
-    "zhetrs2",
-    "zhetrs_rook",
     "zhfrk",
     "zhgeqz",
     "zhpcon",
@@ -1419,7 +1295,6 @@ char *lapack_3_5_0[] = {
     "zlags2",
     "zlagtm",
     "zlahef",
-    "zlahef_rook",
     "zlahqr",
     "zlahr2",
     "zlahrd",
@@ -1443,7 +1318,6 @@ char *lapack_3_5_0[] = {
     "zlantp",
     "zlantr",
     "zlapll",
-    "zlapmr",
     "zlapmt",
     "zlaqgb",
     "zlaqge",
@@ -1467,7 +1341,7 @@ char *lapack_3_5_0[] = {
     "zlarf",
     "zlarfb",
     "zlarfg",
-    "zlarfgp",
+    "zlarfp",
     "zlarft",
     "zlarfx",
     "zlargv",
@@ -1484,7 +1358,6 @@ char *lapack_3_5_0[] = {
     "zlassq",
     "zlaswp",
     "zlasyf",
-    "zlasyf_rook",
     "zlat2c",
     "zlatbs",
     "zlatdf",
@@ -1551,27 +1424,16 @@ char *lapack_3_5_0[] = {
     "zstemr",
     "zsteqr",
     "zsycon",
-    "zsycon_rook",
-    "zsyconv",
     "zsyequb",
     "zsymv",
     "zsyr",
     "zsyrfs",
     "zsysv",
-    "zsysv_rook",
     "zsysvx",
-    "zsyswapr",
     "zsytf2",
-    "zsytf2_rook",
     "zsytrf",
-    "zsytrf_rook",
     "zsytri",
-    "zsytri2",
-    "zsytri2x",
-    "zsytri_rook",
     "zsytrs",
-    "zsytrs2",
-    "zsytrs_rook",
     "ztbcon",
     "ztbrfs",
     "ztbtrs",
@@ -1588,10 +1450,6 @@ char *lapack_3_5_0[] = {
     "ztgsy2",
     "ztgsyl",
     "ztpcon",
-    "ztpmqrt",
-    "ztpqrt",
-    "ztpqrt2",
-    "ztprfb",
     "ztprfs",
     "ztptri",
     "ztptrs",
@@ -1611,15 +1469,6 @@ char *lapack_3_5_0[] = {
     "ztrttp",
     "ztzrqf",
     "ztzrzf",
-    "zunbdb",
-    "zunbdb1",
-    "zunbdb2",
-    "zunbdb3",
-    "zunbdb4",
-    "zunbdb5",
-    "zunbdb6",
-    "zuncsd",
-    "zuncsd2by1",
     "zung2l",
     "zung2r",
     "zungbr",
@@ -1649,7 +1498,7 @@ char *lapack_3_5_0[] = {
     NULL
 };
 
-char *lapack_3_5_0_xblas[] = {
+char *lapack_3_2_0_xblas[] = {
     "cgbrfsx",
     "cgbsvxx",
     "cgerfsx",
@@ -1665,7 +1514,6 @@ char *lapack_3_5_0_xblas[] = {
     "cla_gercond_c",
     "cla_gercond_x",
     "cla_gerfsx_extended",
-    "cla_gerpvgrw",
     "cla_heamv",
     "cla_hercond_c",
     "cla_hercond_x",
@@ -1676,6 +1524,7 @@ char *lapack_3_5_0_xblas[] = {
     "cla_porcond_x",
     "cla_porfsx_extended",
     "cla_porpvgrw",
+    "cla_rpvgrw",
     "cla_syamv",
     "cla_syrcond_c",
     "cla_syrcond_x",
@@ -1699,11 +1548,11 @@ char *lapack_3_5_0_xblas[] = {
     "dla_geamv",
     "dla_gercond",
     "dla_gerfsx_extended",
-    "dla_gerpvgrw",
     "dla_lin_berr",
     "dla_porcond",
     "dla_porfsx_extended",
     "dla_porpvgrw",
+    "dla_rpvgrw",
     "dla_syamv",
     "dla_syrcond",
     "dla_syrfsx_extended",
@@ -1726,11 +1575,11 @@ char *lapack_3_5_0_xblas[] = {
     "sla_geamv",
     "sla_gercond",
     "sla_gerfsx_extended",
-    "sla_gerpvgrw",
     "sla_lin_berr",
     "sla_porcond",
     "sla_porfsx_extended",
     "sla_porpvgrw",
+    "sla_rpvgrw",
     "sla_syamv",
     "sla_syrcond",
     "sla_syrfsx_extended",
@@ -1757,7 +1606,6 @@ char *lapack_3_5_0_xblas[] = {
     "zla_gercond_c",
     "zla_gercond_x",
     "zla_gerfsx_extended",
-    "zla_gerpvgrw",
     "zla_heamv",
     "zla_hercond_c",
     "zla_hercond_x",
@@ -1768,6 +1616,7 @@ char *lapack_3_5_0_xblas[] = {
     "zla_porcond_x",
     "zla_porfsx_extended",
     "zla_porpvgrw",
+    "zla_rpvgrw",
     "zla_syamv",
     "zla_syrcond_c",
     "zla_syrcond_x",
@@ -1782,4 +1631,5 @@ char *lapack_3_5_0_xblas[] = {
     "zsysvxx",
     NULL
 };
-#endif /* end of include guard: LAPACK_3_5_0_H */
+
+#endif /* end of include guard: LAPACK_3_2_0_H */
